"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.repoCreate = void 0;
const constants_1 = require("../../../../../constants");
const extensions_1 = require("../../../../../extensions");
const utils_1 = require("../../../../../utils");
/**
 * Create a new repo
 */
exports.repoCreate = new extensions_1.Command()
    .name("create")
    .description("Create configured repositories")
    .option("-r, --repo-name <repoName>", "Name of repository to create. Will add name to section 'repo.repos' of projector.json")
    .addAction((services, options, config) => __awaiter(void 0, void 0, void 0, function* () {
    const repoConfig = yield getRepoConfig(services, options, config);
    if (!repoConfig) {
        throw new Error(`Section 'repo' of ${constants_1.FileConstants.configFileName} must be configured for this command`);
    }
    const { repos } = repoConfig;
    if (!repos || !repos.length) {
        throw new Error("Need to specify repo names either in 'repo' section of config or with the '--name' option");
    }
    const { repoService } = services;
    if (!repoService) {
        throw new Error("Repo service not instantiated. Make sure you have your 'repo' section configured correctly");
    }
    const createdRepos = yield Promise.all(repos.map((repoName) => repoService.createRepo(repoName)));
    utils_1.Logger.logHeader("Created Repos");
    createdRepos.forEach((repo) => {
        const { name, id, remoteUrl } = repo;
        utils_1.Logger.log(`${id} - ${name} ${remoteUrl}`);
    });
}));
/**
 * Get repo config based on existing configuration and options provided
 *
 * @param {ServiceCollection} services Service collection
 * @param {RepoCreateOptions} options CLI options
 * @param {ProjectorConfig} config Existing projector config
 * @returns {Promise<RepoConfig>} Repo config
 */
function getRepoConfig(services, options, config) {
    return __awaiter(this, void 0, void 0, function* () {
        const { repoName } = options;
        const { repo: repoConfig } = config;
        if (!repoConfig) {
            return undefined;
        }
        const repos = repoConfig.repos || [];
        if (repoName && !repos.find((repo) => repo === repoName)) {
            const { projectorConfigService } = services;
            const newProjectorConfig = Object.assign(Object.assign({}, config), { repo: Object.assign(Object.assign({}, repoConfig), { repos: [...repos, repoName] }) });
            yield projectorConfigService.set(constants_1.FileConstants.configFileName, newProjectorConfig);
            return newProjectorConfig.repo;
        }
        return repoConfig;
    });
}
