"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceCollectionFactory = void 0;
const constants_1 = require("../constants");
const services_1 = require("../services");
const interpolate_1 = require("../services/interpolate");
const object_1 = require("../services/object");
const storage_1 = require("../services/storage");
const utils_1 = require("../utils");
const agileServiceFactory_1 = require("./agileServiceFactory");
const repoServiceFactory_1 = require("./repoServiceFactory");
class ServiceCollectionFactory {
    /**
     * Create collection of shared services
     *
     * @param {ProjectorConfig} config Configuration object
     * @returns {ServiceCollection} Service Collection
     */
    static create(config) {
        return __awaiter(this, void 0, void 0, function* () {
            const localFileStorageService = new storage_1.FileStorageService(process.cwd());
            const parameterService = new object_1.ObjectService(localFileStorageService);
            // TODO: This should change, but it will likely take a large refactor.
            //
            // There's a desire to pass options to commands. Some of the options include
            // filepaths to configuration and different ways to read in configuration
            // files.
            //
            // With DI working as it does now, those options are on commands themselves.
            // But we're instantiating object services before the options are getting
            // evaluated.
            //
            // I've created issue #70 to track this.
            const parameters = yield parameterService.getIfExists(constants_1.FileConstants.parametersFileName);
            const interpolatorService = new interpolate_1.ParameterizedRegexInterpolator(parameters || {});
            const backlogItemTemplateService = new object_1.InterpolatedObjectService(localFileStorageService, interpolatorService);
            const projectorConfigService = new object_1.ObjectService(localFileStorageService);
            const { agile, playbook, repo } = config;
            const contentService = new object_1.ObjectService(localFileStorageService);
            const githubService = new services_1.GitHubRepoService({
                providerName: services_1.RepoServiceProvider.GitHub,
                providerOptions: {
                    owner: utils_1.Config.getValue(constants_1.ConfigKey.PlaybookOwnerName),
                    personalAccessToken: playbook === null || playbook === void 0 ? void 0 : playbook.githubAccessToken,
                },
            }, contentService);
            const playbookService = new services_1.CodeWithPlaybookService(githubService, contentService);
            return {
                agileService: agileServiceFactory_1.AgileServiceFactory.get(agile),
                repoService: repoServiceFactory_1.RepoServiceFactory.get(repo),
                playbookService,
                backlogItemTemplateService,
                parameterService,
                projectorConfigService,
                contentService,
            };
        });
    }
}
exports.ServiceCollectionFactory = ServiceCollectionFactory;
