"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const promises_1 = require("fs/promises");
process.env.NODE_CONFIG_DIR = path_1.join(__dirname, "..", "config");
const utils_1 = require("../utils");
/**
 * Get the base URL for the Azure DevOps organization
 *
 * @returns {Promise<string>} Base URL
 */
function getBaseUrl() {
    return __awaiter(this, void 0, void 0, function* () {
        return utils_1.UserUtils.askQuestion("What is your Azure DevOps test instance base url?");
    });
}
/**
 * Get the name for the Azure DevOps project
 *
 * @returns {Promise<string>} Project name
 */
function getProjectName() {
    return __awaiter(this, void 0, void 0, function* () {
        return utils_1.UserUtils.askQuestion("What is your Azure DevOps test project name? (Must be Agile-enabled)");
    });
}
/**
 * Get the access token for the Azure DevOps instance
 *
 * @param {string} baseUrl Base URL for Azure DevOps
 * @returns {Promise<string>} Access token
 */
function getAzDOToken(baseUrl) {
    return __awaiter(this, void 0, void 0, function* () {
        return utils_1.UserUtils.askQuestion(`Please provide an Azure DevOps access token. Go to ${baseUrl}/_userSettings/tokens to create one`);
    });
}
/**
 * Get the GitHub personal access token
 *
 * @returns {Promise<string>} Access token
 */
function getGitHubToken() {
    return __awaiter(this, void 0, void 0, function* () {
        return utils_1.UserUtils.askQuestion("Please provide a GitHub access token. Go to https://github.com/settings/tokens to create one");
    });
}
/**
 * Creates a .env file in the current working directory
 */
function createDotenvFile() {
    return __awaiter(this, void 0, void 0, function* () {
        utils_1.Logger.log([
            "This script will generate your local .env file required for running tests",
            "Without it, the integration tests will fail\n",
        ].join("\n"));
        const baseUrl = yield getBaseUrl();
        const projectName = yield getProjectName();
        const azdoToken = yield getAzDOToken(baseUrl);
        const githubToken = yield getGitHubToken();
        const dotenvContent = [
            `GITHUB_TOKEN=${githubToken}`,
            `AZURE_DEVOPS_PROJECT_NAME=${projectName}`,
            `AZURE_DEVOPS_BASE_URL=${baseUrl}`,
            `AZURE_DEVOPS_ACCESS_TOKEN=${azdoToken}`,
        ].join("\n");
        utils_1.Logger.log(`\n\n.env content:\n\n${dotenvContent}`);
        yield promises_1.writeFile(".env", dotenvContent);
    });
}
createDotenvFile();
