"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigService = void 0;
const constants_1 = require("../../constants");
const utils_1 = require("../../utils");
/**
 * Class dealing with the Projector configuration.
 */
class ConfigService {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/explicit-module-boundary-types
    static createInitialConfig(options) {
        const { agileProvider, repoProvider } = options;
        return {
            agile: agileProvider ? this.createAgileConfig(agileProvider) : undefined,
            playbook: this.createPlaybookConfig(),
            repo: repoProvider ? this.createRepoConfig(repoProvider) : undefined,
        };
    }
    static overrideConfigWithOptions(config, options) {
        const githubToken = options === null || options === void 0 ? void 0 : options.githubToken;
        if (!githubToken) {
            return config ? config : {};
        }
        if (!config) {
            return {
                playbook: {
                    githubAccessToken: githubToken,
                },
            };
        }
        return Object.assign(Object.assign({}, config), { playbook: Object.assign(Object.assign({}, config.playbook), { githubAccessToken: githubToken }) });
    }
    static createAgileConfig(provider) {
        const now = new Date();
        return {
            providerName: provider,
            providerOptions: this.getProviderOptions(),
            sprints: {
                startDate: `${now.getFullYear()}-${now.getMonth() + 1}-${now.getDate()}`,
                lengthOfSprintInDays: utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultSprintLength),
                daysBetweenSprints: utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultDaysBetweenSprints),
                numberOfSprints: utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultNumberOfSprints),
                sprintIndexStart: utils_1.Config.getValue(constants_1.ConfigKey.AgileDefaultSprintStartIndex),
            },
        };
    }
    static createPlaybookConfig() {
        return {
            githubAccessToken: "{Not required, but allows for greater API limit when reading from GitHub repos}",
        };
    }
    static createRepoConfig(provider) {
        return {
            providerName: provider,
            providerOptions: this.getProviderOptions(),
            repos: [],
        };
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    static getProviderOptions() {
        // Only support AzDO for now. Leaving this here for when there are more options
        return {
            baseUrl: "{Base URL for Azure DevOps organization}",
            projectName: "{Name of Azure DevOps project}",
            personalAccessToken: "{Go to 'https://dev.azure.com/{organization}/_usersSettings/tokens' to generate token}",
        };
    }
}
exports.ConfigService = ConfigService;
