"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InterpolatedObjectService = void 0;
const _1 = require(".");
/**
 * A ObjectService which has an InterpolatorService. The ObjectService uses the
 * InterpolatorService to interpolate objects.
 */
class InterpolatedObjectService extends _1.ObjectService {
    /**
     * Creates an InterpolatedObjectService.
     *
     * @param {StorageService} storageService The storage service backing.
     * @param {InterpolatorService} interpolatorService The interpolator service
     * backing.
     *
     * @returns {InterpolatedObjectService} An instance of an
     * InterpolatedObjectService.
     */
    constructor(storageService, interpolatorService) {
        super(storageService);
        this.interpolatorService = interpolatorService;
    }
    interpolate(content) {
        return this.interpolatorService.interpolate(content);
    }
}
exports.InterpolatedObjectService = InterpolatedObjectService;
