"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AzureDevOpsRepoService = void 0;
const azure_devops_node_api_1 = require("azure-devops-node-api");
const CoreApi_1 = require("azure-devops-node-api/CoreApi");
const GitApi_1 = require("azure-devops-node-api/GitApi");
const utils_1 = require("../../../utils");
const baseRepoService_1 = require("../baseRepoService");
class AzureDevOpsRepoService extends baseRepoService_1.BaseRepoService {
    constructor(config, contentService) {
        super(config, contentService);
        this.listRepos = () => __awaiter(this, void 0, void 0, function* () {
            const repos = yield this.gitApi.getRepositories(this.projectName);
            if (!repos) {
                return undefined;
            }
            return repos.map(this.mapRepo);
        });
        this.getRepo = (repoName) => __awaiter(this, void 0, void 0, function* () {
            const repo = yield this.gitApi.getRepository(repoName, this.projectName);
            if (!repo) {
                return undefined;
            }
            return this.mapRepo(repo);
        });
        this.createRepo = (repoName) => __awaiter(this, void 0, void 0, function* () {
            const existingRepo = yield this.getRepo(repoName);
            if (existingRepo) {
                return existingRepo;
            }
            const project = yield this.coreApi.getProject(this.projectName);
            const gitRepo = yield this.gitApi.createRepository({
                name: repoName,
                project: {
                    id: project.id,
                },
            }, this.projectName);
            return this.mapRepo(gitRepo);
        });
        this.deleteRepo = (repoId) => __awaiter(this, void 0, void 0, function* () {
            return this.gitApi.deleteRepository(repoId, this.projectName);
        });
        this.getRepoItem = () => __awaiter(this, void 0, void 0, function* () {
            throw new Error("Not implemented");
        });
        this.latestCommit = () => __awaiter(this, void 0, void 0, function* () {
            throw new Error("Not implemented");
        });
        const { projectName, baseUrl, personalAccessToken } = utils_1.AzureDevOpsUtils.getProviderOptionsWithConfigDefaults(config.providerOptions);
        this.projectName = projectName;
        const authHandler = azure_devops_node_api_1.getPersonalAccessTokenHandler(personalAccessToken);
        this.gitApi = new GitApi_1.GitApi(baseUrl, [authHandler]);
        this.coreApi = new CoreApi_1.CoreApi(baseUrl, [authHandler]);
    }
    mapRepo(repo) {
        const { name, id, remoteUrl } = repo;
        return {
            name: name,
            id,
            remoteUrl,
        };
    }
}
exports.AzureDevOpsRepoService = AzureDevOpsRepoService;
