"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubRepoService = void 0;
const rest_1 = require("@octokit/rest");
const axios_1 = __importDefault(require("axios"));
const path_1 = require("path");
const constants_1 = require("../../../constants");
const models_1 = require("../../../models");
const utils_1 = require("../../../utils");
const baseRepoService_1 = require("../baseRepoService");
class GitHubRepoService extends baseRepoService_1.BaseRepoService {
    constructor(config, contentService) {
        super(config, contentService);
        this.listRepos = () => __awaiter(this, void 0, void 0, function* () {
            throw new Error("Not implemented");
        });
        this.getRepo = () => __awaiter(this, void 0, void 0, function* () {
            throw new Error("Not implemented");
        });
        this.createRepo = () => {
            throw new Error("Not implemented");
        };
        this.deleteRepo = () => {
            throw new Error("Not implemented");
        };
        this.getRepoItem = (repo, path = "", includeContent, branch) => __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.github.repos.getContent({
                owner: this.owner,
                repo,
                path,
                ref: branch,
            });
            if (data instanceof Array) {
                const children = yield Promise.all(
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                data.map((item) => __awaiter(this, void 0, void 0, function* () {
                    return this.getRepoItem(repo, item.path, includeContent);
                })));
                return {
                    name: path_1.basename(path),
                    type: models_1.RepoItemType.Directory,
                    path,
                    children,
                };
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                const { download_url } = data;
                return {
                    name: path_1.basename(path),
                    type: models_1.RepoItemType.File,
                    path,
                    content: includeContent ? (yield axios_1.default.get(download_url)).data : undefined,
                };
            }
        });
        this.latestCommit = (repo, branch = "main") => __awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.github.repos.getCommit({
                owner: this.owner,
                repo,
                ref: branch,
            });
            const { sha } = data;
            if (!sha) {
                throw new Error(`Could not find latest commit for ${this.owner}/${repo}`);
            }
            return sha;
        });
        const { owner, personalAccessToken } = config.providerOptions;
        this.owner = owner;
        // Prefer environment variable over config
        const accessToken = utils_1.Config.getValueWithDefault(constants_1.ConfigKey.GithubAccessToken, personalAccessToken);
        this.github = new rest_1.Octokit({
            userAgent: "projector",
            auth: accessToken,
        });
    }
}
exports.GitHubRepoService = GitHubRepoService;
