"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileStorageService = void 0;
const promises_1 = require("fs/promises");
const path_1 = require("path");
const utils_1 = require("../../utils");
class FileStorageService {
    constructor(defaultWriteLocation) {
        this.defaultWriteLocation = defaultWriteLocation;
    }
    find(fileName, startingDirectory) {
        return __awaiter(this, void 0, void 0, function* () {
            const path = startingDirectory !== null && startingDirectory !== void 0 ? startingDirectory : this.defaultWriteLocation;
            const filePath = yield this.read(fileName, path);
            if (filePath) {
                return filePath;
            }
            for (let parentDirectory = path; parentDirectory !== startingDirectory || parentDirectory !== path_1.sep; parentDirectory = path_1.join(parentDirectory, "..")) {
                try {
                    const directory = yield promises_1.realpath(parentDirectory);
                    return this.find(fileName, directory);
                }
                catch (e) {
                    if (e.code !== "ENOENT") {
                        throw e;
                    }
                    /** otherwise, that didn't exist, so just swallow it */
                }
            }
            return undefined;
        });
    }
    read(fileName, directory) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const path = directory !== null && directory !== void 0 ? directory : this.defaultWriteLocation;
                const filePath = path_1.join(path, fileName);
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                const content = yield promises_1.readFile(filePath, FileStorageService.readWriteOptions);
                // TODO: remove this check, the readFile call above should deal with encoding
                if (content instanceof Buffer) {
                    return content.toString("utf-8");
                }
                return content;
            }
            catch (e) {
                if (e.code === "ENOENT") {
                    return undefined;
                }
                else {
                    throw e;
                }
            }
        });
    }
    write(fileName, content, directory) {
        return __awaiter(this, void 0, void 0, function* () {
            const path = directory !== null && directory !== void 0 ? directory : this.defaultWriteLocation;
            const filePath = path_1.join(path, fileName);
            try {
                yield promises_1.writeFile(filePath, content, FileStorageService.readWriteOptions);
            }
            catch (err) {
                utils_1.Logger.log(`Could not write file ${fileName} to ${path}:`);
                utils_1.Logger.log(err);
                return false;
            }
            return true;
        });
    }
}
exports.FileStorageService = FileStorageService;
