"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const constants_1 = require("../constants");
const config_1 = __importDefault(require("config"));
const custom_environment_variables_json_1 = __importDefault(require("../config/custom-environment-variables.json"));
class Config {
    static getValue(configKey) {
        return config_1.default.get(configKey);
    }
    static getValueWithDefault(configKey, defaultValue) {
        return config_1.default.has(configKey) ? config_1.default.get(configKey) : defaultValue;
    }
    static getLink(name) {
        const links = this.getValue(constants_1.ConfigKey.Links);
        const matchingLink = links.find((link) => link.name === name);
        if (!matchingLink) {
            throw new Error(`Missing link ${name} in config`);
        }
        return matchingLink;
    }
    static getEnvironmentVariableName(configKey) {
        const splitConfigKey = configKey.split(".");
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        let configObject = custom_environment_variables_json_1.default;
        for (let i = 0; i < splitConfigKey.length; i++) {
            configObject = configObject[splitConfigKey[i]];
            if (!configObject) {
                throw new Error(`Environment variable for config key '${configKey}' not defined`);
            }
        }
        if (typeof configObject === "string") {
            return configObject;
        }
        throw new Error(`Environment variable for config key '${configKey}' not defined`);
    }
    static getUpdatedEnvFileContents(configKey, value, existingEnvFile) {
        const envVarName = Config.getEnvironmentVariableName(configKey);
        const updatedEnvVarLine = `${envVarName}=${value}`;
        const appendOrUpdate = (envFileContents) => {
            return envFileContents.includes(envVarName)
                ? envFileContents.replace(new RegExp(`${envVarName}\\s*=\\s*[^\\s]+`), updatedEnvVarLine)
                : `${envFileContents}\n${updatedEnvVarLine}`;
        };
        return existingEnvFile ? appendOrUpdate(existingEnvFile) : updatedEnvVarLine;
    }
}
exports.Config = Config;
