"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadTemplates = void 0;
const _1 = require(".");
const constants_1 = require("../constants");
const userUtils_1 = require("./userUtils");
/**
 * Downloads a list of templates.
 *
 * @callback saveTemplate
 *
 * @typedef T The type of template to download.
 * @param {() => Promise<T[]>} getTemplates A DI'd function which gets templates.
 * @param {saveTemplate} saveTemplate A DI'd function which saves templates.
 * @param {string?} templateNameOption The optional file name to save the template to.
 * @param {string?} outputPathOption The optional path to save the template to.
 *
 * @returns {Promise<void>} A Promise to download the template.
 */
function downloadTemplates(getTemplates, saveTemplate, templateNameOption, outputPathOption) {
    return __awaiter(this, void 0, void 0, function* () {
        const templates = yield getTemplates();
        const downloadTemplate = (templateName, outPath) => __awaiter(this, void 0, void 0, function* () {
            templateName =
                templateName ||
                    (yield userUtils_1.UserUtils.multiChoiceQuestion("Which template would you like?", templates.map((t) => t.name)));
            if (!templateName) {
                throw new Error("Need a template name");
            }
            const template = templates.find((item) => item.name === templateName);
            if (!template) {
                throw new Error(`Couldn't find template '${templateName}'. Available templates:\n${templates
                    .map((temp) => temp.name)
                    .join("\n")}`);
            }
            const outputFileName = yield userUtils_1.UserUtils.askQuestion("Where would you like to initialize the template?", outPath || constants_1.FileConstants.backlogItemsFileName);
            _1.Logger.log(`Downloading ${templateName} template to ${outputFileName}...`);
            yield saveTemplate(outputFileName, template);
            _1.Logger.log("Success");
        });
        if (templateNameOption) {
            return downloadTemplate(templateNameOption, outputPathOption);
        }
        do {
            yield downloadTemplate(templateNameOption, outputPathOption);
        } while (yield userUtils_1.UserUtils.confirmAction("Would you like to initialize another template?"));
    });
}
exports.downloadTemplates = downloadTemplates;
