"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retryAsync = void 0;
const sleep_1 = require("./sleep");
/**
 * Retry async function for a specified number of times, sleeping between each try
 *
 * @param {any} action Function to be executed
 * @param {number} retriesAllowed Retries allowed. Default to 3
 * @param {number} sleepBetweenRetries Seconds to sleep between tries. Default to 1
 * @returns {Promise} Result of action
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function retryAsync(action, retriesAllowed = 3, sleepBetweenRetries = 1) {
    return __awaiter(this, void 0, void 0, function* () {
        let currentRetries = 0;
        while (currentRetries < retriesAllowed) {
            try {
                return yield action();
            }
            catch (err) {
                currentRetries++;
                yield sleep_1.sleep(sleepBetweenRetries);
            }
        }
        throw new Error(`Reached max number of retries: ${retriesAllowed}`);
    });
}
exports.retryAsync = retryAsync;
