"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserUtils = void 0;
const inquirer_1 = require("inquirer");
const logger_1 = require("./logger");
class UserUtils {
    static confirmAction(message) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.multiChoiceQuestion(message || "Confirm?", ["yes", "no"]);
            return response === "yes";
        });
    }
    static askQuestion(question, defaultAnswer) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield inquirer_1.prompt([
                {
                    type: "input",
                    name: question,
                    default: defaultAnswer,
                },
            ]);
            if (!response) {
                if (defaultAnswer) {
                    return defaultAnswer;
                }
                else {
                    logger_1.Logger.log("Need to answer the question");
                    return this.askQuestion(question, defaultAnswer);
                }
            }
            else {
                return response[question];
            }
        });
    }
    static askNumberQuestion(question, defaultAnswer) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.askQuestion(question, defaultAnswer === null || defaultAnswer === void 0 ? void 0 : defaultAnswer.toString());
            try {
                return +response;
            }
            catch (err) {
                logger_1.Logger.log("Invalid response");
                return this.askNumberQuestion(question, defaultAnswer);
            }
        });
    }
    static multiChoiceQuestion(question, choices) {
        return __awaiter(this, void 0, void 0, function* () {
            const answer = yield inquirer_1.prompt([
                {
                    type: "list",
                    name: question,
                    choices,
                },
            ]);
            return answer[question];
        });
    }
}
exports.UserUtils = UserUtils;
